'''
manage service identities of a VM scaleset.
'''
from ... pyaz_utils import _call_az

def assign(name, resource_group, identities=None, role=None, scope=None):
    '''
    Enable managed service identity on a VMSS.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identities -- Space-separated identities to assign. Use '[system]' to refer to the system assigned identity. Default: '[system]'
    - role -- Role name or id the system assigned identity will have
    - scope -- Scope that the system assigned identity can access
    '''
    return _call_az("az vmss identity assign", locals())


def remove(name, resource_group, identities=None):
    '''
    Remove user assigned identities from a VM scaleset.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identities -- Space-separated identities to remove. Use '[system]' to refer to the system assigned identity. Default: '[system]'
    '''
    return _call_az("az vmss identity remove", locals())


def show(name, resource_group):
    '''
    display VM scaleset's managed identity info.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss identity show", locals())




from ... pyaz_utils import _call_az

def show(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- The name of the Failover Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql failover-group show", locals())


def list(resource_group, server):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql failover-group list", locals())


def create(name, partner_server, resource_group, server, add_db=None, failover_policy=None, grace_period=None, partner_resource_group=None):
    '''
    Creates a failover group.

    Required Parameters:
    - name -- The name of the Failover Group
    - partner_server -- The name of the partner server of a Failover Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - add_db -- List of databases to add to Failover Group
    - failover_policy -- The failover policy of the Failover Group
    - grace_period -- Interval in hours before automatic failover is initiated if an outage occurs on the primary server. This indicates that Azure SQL Database will not initiate automatic failover before the grace period expires. Please note that failover operation with --allow-data-loss option might cause data loss due to the nature of asynchronous synchronization.
    - partner_resource_group -- The name of the resource group of the partner server
    '''
    return _call_az("az sql failover-group create", locals())


def update(name, resource_group, server, add=None, add_db=None, failover_policy=None, force_string=None, grace_period=None, remove=None, remove_db=None, set=None):
    '''
    Updates the failover group.

    Required Parameters:
    - name -- The name of the Failover Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - add_db -- List of databases to add to Failover Group
    - failover_policy -- The failover policy of the Failover Group
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - grace_period -- Interval in hours before automatic failover is initiated if an outage occurs on the primary server. This indicates that Azure SQL Database will not initiate automatic failover before the grace period expires. Please note that failover operation with --allow-data-loss option might cause data loss due to the nature of asynchronous synchronization.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - remove_db -- List of databases to remove from Failover Group
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az sql failover-group update", locals())


def delete(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- The name of the Failover Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql failover-group delete", locals())


def set_primary(name, resource_group, server, allow_data_loss=None):
    '''
    Set the primary of the failover group by failing over all databases from the current primary server.

    Required Parameters:
    - name -- The name of the Failover Group
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - allow_data_loss -- Complete the failover even if doing so may result in data loss. This will allow the failover to proceed even if a primary database is unavailable.
    '''
    return _call_az("az sql failover-group set-primary", locals())




from ... pyaz_utils import _call_az
from . import dns_zone_group


def create(connection_name, name, private_connection_resource_id, resource_group, subnet, edge_zone=None, group_id=None, location=None, manual_request=None, request_message=None, tags=None, vnet_name=None):
    '''
    Create a private endpoint.

    Required Parameters:
    - connection_name -- Name of the private link service connection.
    - name -- Name of the private endpoint.
    - private_connection_resource_id -- The resource id of the private endpoint to connect to
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- Name or ID of an existing subnet. If name specified, also specify --vnet-name. If you want to use an existing subnet in other resource group or subscription, please provide the ID instead of the name of the subnet and do not specify the --vnet-name

    Optional Parameters:
    - edge_zone -- The name of edge zone.
    - group_id -- The ID of the group obtained from the remote resource that this private endpoint should connect to. You can use "az network private-link-resource list" to obtain the supported group ids. You must provide this except for PrivateLinkService
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - manual_request -- Use manual request to establish the connection. Configure it as 'true' when you don't have access to the subscription of private link service.
    - request_message -- A message passed to the owner of the remote resource with this connection request. Restricted to 140 chars.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vnet_name -- The virtual network (VNet) associated with the subnet (Omit if supplying a subnet id).
    '''
    return _call_az("az network private-endpoint create", locals())


def delete(name, resource_group):
    '''
    Delete a private endpoint.

    Required Parameters:
    - name -- Name of the private endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network private-endpoint delete", locals())


def list(resource_group=None):
    '''
    List private endpoints.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network private-endpoint list", locals())


def show(name, resource_group):
    '''
    Get the details of a private endpoint.

    Required Parameters:
    - name -- Name of the private endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network private-endpoint show", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, request_message=None, set=None, tags=None):
    '''
    Update a private endpoint.

    Required Parameters:
    - name -- Name of the private endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - request_message -- A message passed to the owner of the remote resource with this connection request. Restricted to 140 chars.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network private-endpoint update", locals())


def list_types(location):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network private-endpoint list-types", locals())




from .... pyaz_utils import _call_az

def create(account_name, name, sas_type, template_uri, validity_period, vault_name, disabled=None, tags=None):
    '''
    

    Required Parameters:
    - account_name -- Name to identify the storage account in the vault.
    - name -- Name to identify the SAS definition in the vault.
    - sas_type -- The type of SAS token the SAS definition will create. Possible values include: 'account', 'service'
    - template_uri -- The SAS definition token template signed with the key 00000000. In the case of an account token this is only the sas token itself, for service tokens, the full service endpoint url along with the sas token.  Tokens created according to the SAS definition will have the same properties as the template.
    - validity_period -- The validity period of SAS tokens created according to the SAS definition in ISO-8601, such as "PT12H" for 12 hour tokens.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - disabled -- Add the storage account in a disabled state.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az keyvault storage sas-definition create", locals())


def list(account_name, vault_name, maxresults=None):
    '''
    

    Required Parameters:
    - account_name -- Name to identify the storage account in the vault.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    '''
    return _call_az("az keyvault storage sas-definition list", locals())


def show(account_name=None, id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - account_name -- Name to identify the storage account in the vault. Required if --id is not specified.
    - id -- Id of the SAS definition. If specified all other 'Id' arguments should be omitted.
    - name -- Name to identify the SAS definition in the vault. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault storage sas-definition show", locals())


def update(account_name=None, disabled=None, id=None, name=None, sas_type=None, tags=None, template_uri=None, validity_period=None, vault_name=None):
    '''
    

    Optional Parameters:
    - account_name -- Name to identify the storage account in the vault. Required if --id is not specified.
    - disabled -- Add the storage account in a disabled state.
    - id -- Id of the SAS definition. If specified all other 'Id' arguments should be omitted.
    - name -- Name to identify the SAS definition in the vault. Required if --id is not specified.
    - sas_type -- The type of SAS token the SAS definition will create. Possible values include: 'account', 'service'
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - template_uri -- The SAS definition token template signed with the key 00000000. In the case of an account token this is only the sas token itself, for service tokens, the full service endpoint url along with the sas token.  Tokens created according to the SAS definition will have the same properties as the template.
    - validity_period -- The validity period of SAS tokens created according to the SAS definition in ISO-8601, such as "PT12H" for 12 hour tokens.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault storage sas-definition update", locals())


def delete(account_name=None, id=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - account_name -- Name to identify the storage account in the vault. Required if --id is not specified.
    - id -- Id of the SAS definition. If specified all other 'Id' arguments should be omitted.
    - name -- Name to identify the SAS definition in the vault. Required if --id is not specified.
    - vault_name -- Name of the Key Vault. Required if --id is not specified.
    '''
    return _call_az("az keyvault storage sas-definition delete", locals())


def list_deleted(account_name, vault_name, maxresults=None):
    '''
    

    Required Parameters:
    - account_name -- Name to identify the storage account in the vault.
    - vault_name -- Name of the Vault.

    Optional Parameters:
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    '''
    return _call_az("az keyvault storage sas-definition list-deleted", locals())


def show_deleted(account_name, name, vault_name):
    '''
    

    Required Parameters:
    - account_name -- Name to identify the storage account in the vault.
    - name -- Name to identify the SAS definition in the vault.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault storage sas-definition show-deleted", locals())


def recover(account_name, name, vault_name):
    '''
    

    Required Parameters:
    - account_name -- Name to identify the storage account in the vault.
    - name -- Name to identify the SAS definition in the vault.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault storage sas-definition recover", locals())




from ... pyaz_utils import _call_az

def attach(resource_group, vm_name, caching=None, lun=None, name=None, new=None, size_gb=None, vhd_uri=None):
    '''
    Attach an unmanaged persistent disk to a VM.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - caching -- Disk caching policy
    - lun -- 0-based logical unit number (LUN). Max value depends on the Virtual Machine size.
    - name -- The data disk name.
    - new -- Create a new disk.
    - size_gb -- size in GB. Max size: 4095 GB (certain preview disks can be larger).
    - vhd_uri -- Virtual hard disk URI. For example: https://mystorage.blob.core.windows.net/vhds/d1.vhd
    '''
    return _call_az("az vm unmanaged-disk attach", locals())


def detach(name, resource_group, vm_name):
    '''
    Detach an unmanaged disk from a VM.

    Required Parameters:
    - name -- The data disk name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    '''
    return _call_az("az vm unmanaged-disk detach", locals())


def list(resource_group, vm_name):
    '''
    List unmanaged disks of a VM.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    '''
    return _call_az("az vm unmanaged-disk list", locals())




from .... pyaz_utils import _call_az

def add(namespace_name, resource_group, action=None, ignore_missing_endpoint=None, ip_address=None, subnet=None, vnet_name=None):
    '''
    Add a network rule for a namespace.

    Required Parameters:
    - namespace_name -- Name of the Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - action -- Action of the IP rule
    - ignore_missing_endpoint -- A boolean value that indicates whether to ignore missing vnet Service Endpoint
    - ip_address -- IPv4 address or CIDR range - 10.6.0.0/24
    - subnet -- Name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - vnet_name -- Name of the Virtual Network
    '''
    return _call_az("az eventhubs namespace network-rule add", locals())


def list(namespace_name, resource_group):
    '''
    Show properties of Network rule of the given Namespace.

    Required Parameters:
    - namespace_name -- Name of the Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs namespace network-rule list", locals())


def remove(namespace_name, resource_group, ip_address=None, subnet=None, vnet_name=None):
    '''
    Remove network rule for a namespace

    Required Parameters:
    - namespace_name -- Name of the Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - ip_address -- IPv4 address or CIDR range - 10.6.0.0/24
    - subnet -- Name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - vnet_name -- Name of the Virtual Network
    '''
    return _call_az("az eventhubs namespace network-rule remove", locals())




'''
Support data box edge device and management
'''
from .. pyaz_utils import _call_az
from . import alert, bandwidth_schedule, device, order


def show_job(device_name, name, resource_group):
    '''
    Get the details of a specified job on a Data Box Edge/Data Box Gateway device.

    Required Parameters:
    - device_name -- The device name.
    - name -- The job name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databoxedge show-job", locals())


def list_node(device_name, resource_group):
    '''
    Get all the nodes currently configured under this Data Box Edge device.

    Required Parameters:
    - device_name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databoxedge list-node", locals())


def list_sku(filter=None):
    '''
    List all the available Skus in the region and information related to them.

    Optional Parameters:
    - filter -- Specify $filter='location eq <location>' to filter on location.
    '''
    return _call_az("az databoxedge list-sku", locals())




'''
Manage Azure Service Bus Topic and Authorization Rule
'''
from ... pyaz_utils import _call_az
from . import authorization_rule, subscription


def create(name, namespace_name, resource_group, auto_delete_on_idle=None, default_message_time_to_live=None, duplicate_detection_history_time_window=None, enable_batched_operations=None, enable_duplicate_detection=None, enable_express=None, enable_ordering=None, enable_partitioning=None, max_size=None, status=None):
    '''
    Create the Service Bus Topic

    Required Parameters:
    - name -- Name of Topic
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - auto_delete_on_idle -- ISO 8601 timespan or duration time format for idle interval after which the topic is automatically deleted. The minimum duration is 5 minutes.
    - default_message_time_to_live -- ISO 8601 or duration time format for Default message timespan to live value. This is the duration after which the message expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not set on a message itself.
    - duplicate_detection_history_time_window -- ISO 8601 timespan or duration time format for structure that defines the duration of the duplicate detection history. The default value is 10 minutes.
    - enable_batched_operations -- Allow server-side batched operations.
    - enable_duplicate_detection -- A boolean value indicating if this topic requires duplicate detection.
    - enable_express -- A boolean value that indicates whether Express Entities are enabled. An express topic holds a message in memory temporarily before writing it to persistent storage.
    - enable_ordering -- A boolean value that indicates whether the topic supports ordering.
    - enable_partitioning -- A boolean value that indicates whether the topic to be partitioned across multiple message brokers is enabled.
    - max_size -- Maximum size of topic in megabytes, which is the size of the memory allocated for the topic. Default is 1024. Max for Standard SKU is 5120 and for Premium SKU is 81920
    - status -- Enumerates the possible values for the status of a messaging entity.
    '''
    return _call_az("az servicebus topic create", locals())


def show(name, namespace_name, resource_group):
    '''
    Shows the Service Bus Topic Details

    Required Parameters:
    - name -- Name of Topic
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus topic show", locals())


def list(namespace_name, resource_group, skip=None, top=None):
    '''
    List the Topic by Service Bus Namespace

    Required Parameters:
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - skip -- Skip is only used if a previous operation returned a partial result. If a previous response contains a nextLink element, the value of the nextLink element will include a skip parameter that specifies a starting point to use for subsequent calls.
    - top -- May be used to limit the number of results to the most recent N usageDetails.
    '''
    return _call_az("az servicebus topic list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Service Bus Topic

    Required Parameters:
    - name -- Name of Topic
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus topic delete", locals())


def update(name, namespace_name, resource_group, add=None, auto_delete_on_idle=None, default_message_time_to_live=None, duplicate_detection_history_time_window=None, enable_batched_operations=None, enable_duplicate_detection=None, enable_express=None, enable_ordering=None, enable_partitioning=None, force_string=None, max_size=None, remove=None, set=None, status=None):
    '''
    Updates the Service Bus Topic

    Required Parameters:
    - name -- Name of Topic
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - auto_delete_on_idle -- ISO 8601 timespan or duration time format for idle interval after which the topic is automatically deleted. The minimum duration is 5 minutes.
    - default_message_time_to_live -- ISO 8601 or duration time format for Default message timespan to live value. This is the duration after which the message expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not set on a message itself.
    - duplicate_detection_history_time_window -- ISO 8601 timespan or duration time format for structure that defines the duration of the duplicate detection history. The default value is 10 minutes.
    - enable_batched_operations -- Allow server-side batched operations.
    - enable_duplicate_detection -- A boolean value indicating if this topic requires duplicate detection.
    - enable_express -- A boolean value that indicates whether Express Entities are enabled. An express topic holds a message in memory temporarily before writing it to persistent storage.
    - enable_ordering -- A boolean value that indicates whether the topic supports ordering.
    - enable_partitioning -- A boolean value that indicates whether the topic to be partitioned across multiple message brokers is enabled.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - max_size -- Maximum size of topic in megabytes, which is the size of the memory allocated for the topic. Default is 1024. Max for Standard SKU is 5120 and for Premium SKU is 81920
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - status -- Enumerates the possible values for the status of a messaging entity.
    '''
    return _call_az("az servicebus topic update", locals())




from ... pyaz_utils import _call_az
from . import version


def list(cluster_name, resource_group):
    '''
    List application types of a given cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf application-type list", locals())


def delete(cluster_name, name, resource_group):
    '''
    Delete an application type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf application-type delete", locals())


def show(cluster_name, name, resource_group):
    '''
    Show the properties of an application type on an Azure Service Fabric cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf application-type show", locals())


def create(cluster_name, name, resource_group):
    '''
    Create a new application type on an Azure Service Fabric cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf application-type create", locals())




'''
Manage Azure NetApp Files (ANF) Account Backup Resources.
'''
from .... pyaz_utils import _call_az

def show(account_name, backup_name, resource_group):
    '''
    Get Backup for a Netapp Files (ANF) Account.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_name -- The name of the backup.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account backup show", locals())


def list(account_name, resource_group):
    '''
    Get list of all Azure NetApp Files (ANF) Account Backups.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account backup list", locals())


def delete(account_name, backup_name, resource_group, yes=None):
    '''
    Delete Backup for a Netapp Files (ANF) Account.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_name -- The name of the backup.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az netappfiles account backup delete", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    List registered topic types.
    '''
    return _call_az("az eventgrid topic-type list", locals())


def show(name):
    '''
    Get the details for a topic type.

    Required Parameters:
    - name -- Name of the topic type.
    '''
    return _call_az("az eventgrid topic-type show", locals())


def list_event_types(name):
    '''
    List the event types supported by a topic type.

    Required Parameters:
    - name -- Name of the topic type.
    '''
    return _call_az("az eventgrid topic-type list-event-types", locals())




'''
Manage App Service Environments
'''
from ... pyaz_utils import _call_az

def list(resource_group=None):
    '''
    List app service environments.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appservice ase list", locals())


def list_addresses(name, resource_group=None):
    '''
    List VIPs associated with an app service environment v2.

    Required Parameters:
    - name -- Name of the app service environment

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appservice ase list-addresses", locals())


def list_plans(name, resource_group=None):
    '''
    List app service plans associated with an app service environment.

    Required Parameters:
    - name -- Name of the app service environment

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appservice ase list-plans", locals())


def show(name, resource_group=None):
    '''
    Show details of an app service environment.

    Required Parameters:
    - name -- Name of the app service environment

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appservice ase show", locals())


def create(name, resource_group, subnet, force_network_security_group=None, force_route_table=None, front_end_scale_factor=None, front_end_sku=None, ignore_network_security_group=None, ignore_route_table=None, ignore_subnet_size_validation=None, kind=None, location=None, no_wait=None, os_preference=None, virtual_ip_type=None, vnet_name=None, zone_redundant=None):
    '''
    Create app service environment.

    Required Parameters:
    - name -- Name of the app service environment
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- Name or ID of existing subnet. To create vnet and/or subnet                    use `az network vnet [subnet] create`

    Optional Parameters:
    - force_network_security_group -- Override network security group for subnet. Applies to ASEv2 only.
    - force_route_table -- Override route table for subnet. Applies to ASEv2 only.
    - front_end_scale_factor -- Scale of front ends to app service plan instance ratio. Applies to ASEv2 only.
    - front_end_sku -- Size of front end servers. Applies to ASEv2 only.
    - ignore_network_security_group -- Configure network security group manually. Applies to ASEv2 only.
    - ignore_route_table -- Configure route table manually. Applies to ASEv2 only.
    - ignore_subnet_size_validation -- Do not check if subnet is sized according to recommendations.
    - kind -- Specify App Service Environment version
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - os_preference -- Determine if app service environment should start with Linux workers. Applies to ASEv2 only.
    - virtual_ip_type -- Specify if app service environment should be accessible from internet
    - vnet_name -- Name of the vNet. Mandatory if only subnet name is specified.
    - zone_redundant -- Configure App Service Environment as Zone Redundant. Applies to ASEv3 only.
    '''
    return _call_az("az appservice ase create", locals())


def update(name, allow_new_private_endpoint_connections=None, front_end_scale_factor=None, front_end_sku=None, no_wait=None, resource_group=None):
    '''
    Update app service environment.

    Required Parameters:
    - name -- Name of the app service environment

    Optional Parameters:
    - allow_new_private_endpoint_connections -- (ASEv3 only) Configure Apps in App Service Environment to allow new private endpoint connections.
    - front_end_scale_factor -- (ASEv2 only) Scale of front ends to app service plan instance ratio between 5 and 15.
    - front_end_sku -- (ASEv2 only) Size of front end servers.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az appservice ase update", locals())


def delete(name, no_wait=None, resource_group=None, yes=None):
    '''
    Delete app service environment.

    Required Parameters:
    - name -- Name of the app service environment

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az appservice ase delete", locals())


def create_inbound_services(name, resource_group, subnet, skip_dns=None, vnet_name=None):
    '''
    Private DNS Zone for Internal ASEv2.

    Required Parameters:
    - name -- Name of the app service environment
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- Name or ID of existing subnet for inbound traffic to ASEv3.                    To create vnet and/or subnet use `az network vnet [subnet] create`

    Optional Parameters:
    - skip_dns -- Do not create Private DNS Zone and DNS records.
    - vnet_name -- Name of the vNet. Mandatory if only subnet name is specified.
    '''
    return _call_az("az appservice ase create-inbound-services", locals())




from ..... pyaz_utils import _call_az

def list(resource_group, workspace_name):
    '''
    List all the tables for the given Log Analytics workspace.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace table list", locals())


def show(name, resource_group, workspace_name):
    '''
    Get a Log Analytics workspace table.

    Required Parameters:
    - name -- Name of the table.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace table show", locals())


def update(name, resource_group, retention_time, workspace_name):
    '''
    Update the properties of a Log Analytics workspace table, currently only support updating retention time.

    Required Parameters:
    - name -- Name of the table.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - retention_time -- The data table data retention in days, between 30 and 730. Setting this property to null will default to the workspace
    - workspace_name -- Name of the Log Analytics Workspace.
    '''
    return _call_az("az monitor log-analytics workspace table update", locals())




'''
Manage protection of your items, enable protection or disable it, or take on-demand backups.
'''
from ... pyaz_utils import _call_az

def check_vm(resource_group=None, vm=None, vm_id=None):
    '''
    Find out whether the virtual machine is protected or not. If protected, it returns the recovery services vault ID, otherwise it returns empty.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vm -- Name or ID of the Virtual Machine to be protected.
    - vm_id -- ID of the virtual machine to be checked for protection.
    '''
    return _call_az("az backup protection check-vm", locals())


def enable_for_vm(policy_name, resource_group, vault_name, vm, disk_list_setting=None, diskslist=None, exclude_all_data_disks=None):
    '''
    Start protecting a previously unprotected Azure VM as per the specified policy to a Recovery services vault.

    Required Parameters:
    - policy_name -- Name of the backup policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.
    - vm -- Name or ID of the Virtual Machine to be protected.

    Optional Parameters:
    - disk_list_setting -- option to decide whether to include or exclude the disk or reset any previous settings to default behavior
    - diskslist -- List of disks to be excluded or included.
    - exclude_all_data_disks -- Option to specify to backup OS disk only.
    '''
    return _call_az("az backup protection enable-for-vm", locals())


def update_for_vm(container_name, item_name, resource_group, vault_name, disk_list_setting=None, diskslist=None, exclude_all_data_disks=None):
    '''
    Update disk exclusion settings associated with a backed up VM item.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - disk_list_setting -- option to decide whether to include or exclude the disk or reset any previous settings to default behavior
    - diskslist -- List of disks to be excluded or included.
    - exclude_all_data_disks -- Option to specify to backup OS disk only.
    '''
    return _call_az("az backup protection update-for-vm", locals())


def backup_now(item_name, resource_group, vault_name, backup_management_type=None, backup_type=None, container_name=None, enable_compression=None, retain_until=None, workload_type=None):
    '''
    Perform an on-demand backup of a backed up item.

    Required Parameters:
    - item_name -- Name of the backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - backup_type -- 'Full, Differential, Log, CopyOnlyFull' for backup Item type 'MSSQL'. 'Full, Differential' for backup item type 'SAPHANA'.
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - enable_compression -- Option to enable compression
    - retain_until -- The date until which this backed up copy will be available for retrieval, in UTC (d-m-Y). For SQL workload, retain-until can only be specified for backup-type 'CopyOnlyFull'. For HANA workload, user can't specify the value for retain-until. If not specified, 30 days will be taken as default value or as decided by service.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup protection backup-now", locals())


def disable(container_name, item_name, resource_group, vault_name, backup_management_type=None, delete_backup_data=None, workload_type=None, yes=None):
    '''
    Stop protecting a backed up item. Can retain the backed up data forever or choose to delete it.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - delete_backup_data -- Option to delete existing backed up data in the Recovery services vault.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az backup protection disable", locals())


def enable_for_azurefileshare(azure_file_share, policy_name, resource_group, storage_account, vault_name):
    '''
    Start protecting a previously unprotected Azure File share within an Azure Storage account as per the specified policy to a Recovery services vault.

    Required Parameters:
    - azure_file_share -- Name of the Azure FileShare.
    - policy_name -- Name of the backup policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_account -- Name of the Storage Account of the FileShare.
    - vault_name -- Name of the Recovery services vault.
    '''
    return _call_az("az backup protection enable-for-azurefileshare", locals())


def enable_for_azurewl(policy_name, protectable_item_name, protectable_item_type, resource_group, server_name, vault_name, workload_type):
    '''
    Start protecting a previously unprotected workload within an Azure VM as per the specified policy to a Recovery services vault. Provide the workload details as a protectable item.

    Required Parameters:
    - policy_name -- Name of the backup policy.
    - protectable_item_name -- Specify the resource name to be protected by Azure Backup service.
    - protectable_item_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Parent Server name of the item.
    - vault_name -- Name of the Recovery services vault.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup protection enable-for-azurewl", locals())


def auto_enable_for_azurewl(policy_name, protectable_item_name, protectable_item_type, resource_group, server_name, vault_name, workload_type):
    '''
    Automatically protect all existing unprotected DBs and any DB which will be added later with the given policy.

    Required Parameters:
    - policy_name -- Name of the backup policy.
    - protectable_item_name -- Specify the resource name to be protected by Azure Backup service.
    - protectable_item_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Parent Server name of the item.
    - vault_name -- Name of the Recovery services vault.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup protection auto-enable-for-azurewl", locals())


def auto_disable_for_azurewl(protectable_item_name, protectable_item_type, resource_group, server_name, vault_name, workload_type):
    '''
    Disable auto-protection for the specified protectable item.

    Required Parameters:
    - protectable_item_name -- Specify the resource name to be protected by Azure Backup service.
    - protectable_item_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Parent Server name of the item.
    - vault_name -- Name of the Recovery services vault.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup protection auto-disable-for-azurewl", locals())


def resume(container_name, item_name, policy_name, resource_group, vault_name, backup_management_type=None, workload_type=None):
    '''
    Resume backup for the associated backup item. Use this to change the policy associated with the backup item.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - policy_name -- Name of the backup policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup protection resume", locals())


def undelete(container_name, item_name, resource_group, vault_name, backup_management_type=None, workload_type=None):
    '''
    Rehydrate an item from softdeleted state to stop protection with retained data state.

    Required Parameters:
    - container_name -- Name of the backup container. Accepts 'Name' or 'FriendlyName' from the output of az backup container list command. If 'FriendlyName' is passed then BackupManagementType is required.
    - item_name -- Name of the backed up item.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vault_name -- Name of the Recovery services vault.

    Optional Parameters:
    - backup_management_type -- Specify the backup management type. Define how Azure Backup manages the backup of entities within the ARM resource. For eg: AzureWorkloads refers to workloads installed within Azure VMs, AzureStorage refers to entities within Storage account. Required only if friendly name is used as Container name.
    - workload_type -- Specify the type of applications within the Resource which should be discovered and protected by Azure Backup. 
    '''
    return _call_az("az backup protection undelete", locals())




from ... pyaz_utils import _call_az

def show(profile_name, resource_group, rule_set_name):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_name -- Name of the rule set.
    '''
    return _call_az("az afd rule-set show", locals())


def list(profile_name, resource_group):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd rule-set list", locals())


def create(profile_name, resource_group, rule_set_name):
    '''
    Creates a new rule set under the specified profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_name -- Name of the rule set.
    '''
    return _call_az("az afd rule-set create", locals())


def delete(profile_name, resource_group, rule_set_name, yes=None):
    '''
    Delete the rule set.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_set_name -- Name of the rule set.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az afd rule-set delete", locals())




'''
Manage function app deployment slots.
'''
from .... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    List all deployment slots.

    Required Parameters:
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az functionapp deployment slot list", locals())


def delete(name, resource_group, slot):
    '''
    Delete a deployment slot.

    Required Parameters:
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - slot -- the name of the slot
    '''
    return _call_az("az functionapp deployment slot delete", locals())


def auto_swap(name, resource_group, slot, auto_swap_slot=None, disable=None):
    '''
    Configure deployment slot auto swap.

    Required Parameters:
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - slot -- the name of the slot

    Optional Parameters:
    - auto_swap_slot -- target slot to auto swap
    - disable -- disable auto swap
    '''
    return _call_az("az functionapp deployment slot auto-swap", locals())


def swap(name, resource_group, slot, action=None, preserve_vnet=None, target_slot=None):
    '''
    Swap deployment slots for a function app.

    Required Parameters:
    - name -- Name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - slot -- the name of the slot

    Optional Parameters:
    - action -- swap types. use 'preview' to apply target slot's settings on the source slot first; use 'swap' to complete it; use 'reset' to reset the swap
    - preserve_vnet -- preserve Virtual Network to the slot during swap, default to 'true'
    - target_slot -- target slot to swap, default to 'production'
    '''
    return _call_az("az functionapp deployment slot swap", locals())


def create(name, resource_group, slot, configuration_source=None):
    '''
    Create a deployment slot.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - slot -- the name of the slot

    Optional Parameters:
    - configuration_source -- source slot to clone configurations from. Use function app's name to refer to the production slot
    '''
    return _call_az("az functionapp deployment slot create", locals())




from .... pyaz_utils import _call_az

def create(resource_group, server_name, display_name=None, object_id=None):
    '''
    Create a new server Active Directory administrator.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - display_name -- Display name of the Azure AD administrator user or group.
    - object_id -- The unique ID of the Azure AD administrator.
    '''
    return _call_az("az sql server ad-admin create", locals())


def list(resource_group, server_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server ad-admin list", locals())


def delete(resource_group, server_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server ad-admin delete", locals())


def update(resource_group, server_name, add=None, display_name=None, force_string=None, object_id=None, remove=None, set=None):
    '''
    Update an existing server Active Directory administrator.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - display_name -- Display name of the Azure AD administrator user or group.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - object_id -- The unique ID of the Azure AD administrator.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az sql server ad-admin update", locals())




from ... pyaz_utils import _call_az

def create(cluster_name, data_center_location, data_center_name, delegated_subnet_id, node_count, resource_group, availability_zone=None, backup_storage_customer_key_uri=None, base64_encoded_cassandra_yaml_fragment=None, disk_capacity=None, disk_sku=None, managed_disk_customer_key_uri=None, no_wait=None, sku=None):
    '''
    Create a Datacenter in an Azure Managed Cassandra Cluster.

    Required Parameters:
    - cluster_name -- Cluster Name
    - data_center_location -- Azure Location of the Datacenter
    - data_center_name -- Datacenter Name
    - delegated_subnet_id -- The resource id of a subnet where ip addresses of the Cassandra virtual machines will be allocated. This must be in the same region as data_center_location.
    - node_count -- The number of Cassandra virtual machines in this data center. The minimum value is 3.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - availability_zone -- If the data center haves Availability Zone feature, apply it to the Virtual Machine ScaleSet that host the data center virtual machines.
    - backup_storage_customer_key_uri -- Indicates the Key Uri of the customer key to use for encryption of the backup storage account.
    - base64_encoded_cassandra_yaml_fragment -- This is a Base64 encoded yaml file that is a subset of cassandra.yaml.  Supported fields will be honored and others will be ignored.
    - disk_capacity -- Number of disk used for data centers. Default value is 4.
    - disk_sku -- Disk SKU used for data centers. Default value is P30.
    - managed_disk_customer_key_uri -- Key uri to use for encryption of managed disks. Ensure the system assigned identity of the cluster has been assigned appropriate permissions(key get/wrap/unwrap permissions) on the key.
    - no_wait -- Do not wait for the long-running operation to finish.
    - sku -- Virtual Machine SKU used for data centers. Default value is Standard_DS14_v2
    '''
    return _call_az("az managed-cassandra datacenter create", locals())


def update(cluster_name, data_center_name, resource_group, backup_storage_customer_key_uri=None, base64_encoded_cassandra_yaml_fragment=None, managed_disk_customer_key_uri=None, no_wait=None, node_count=None):
    '''
    Update a Datacenter in an Azure Managed Cassandra Cluster.

    Required Parameters:
    - cluster_name -- Cluster Name
    - data_center_name -- Datacenter Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - backup_storage_customer_key_uri -- Indicates the Key Uri of the customer key to use for encryption of the backup storage account.
    - base64_encoded_cassandra_yaml_fragment -- This is a Base64 encoded yaml file that is a subset of cassandra.yaml.  Supported fields will be honored and others will be ignored.
    - managed_disk_customer_key_uri -- Key uri to use for encryption of managed disks. Ensure the system assigned identity of the cluster has been assigned appropriate permissions(key get/wrap/unwrap permissions) on the key.
    - no_wait -- Do not wait for the long-running operation to finish.
    - node_count -- The number of Cassandra virtual machines in this data center. The minimum value is 3.
    '''
    return _call_az("az managed-cassandra datacenter update", locals())


def list(cluster_name, resource_group):
    '''
    List the Managed Cassandra Datacenters in a given Cluster.

    Required Parameters:
    - cluster_name -- Cluster Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az managed-cassandra datacenter list", locals())


def show(cluster_name, data_center_name, resource_group):
    '''
    Get a Managed Cassandra DataCenter Resource.

    Required Parameters:
    - cluster_name -- Cluster Name
    - data_center_name -- Datacenter Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az managed-cassandra datacenter show", locals())


def delete(cluster_name, data_center_name, resource_group, no_wait=None, yes=None):
    '''
    Deletes a Managed Cassandra Datacenter.

    Required Parameters:
    - cluster_name -- Cluster Name
    - data_center_name -- Datacenter Name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az managed-cassandra datacenter delete", locals())




from ... pyaz_utils import _call_az

def list(hsm_name=None, resource_group=None, vault_name=None):
    '''
    List the private link resources supported for a Key Vault/HSM.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --name/-n are mutually exclusive, please specify just one of them)
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault private-link-resource list", locals())




'''
Manage the virtual router peering.
'''
from .... pyaz_utils import _call_az

def create(name, peer_asn, peer_ip, resource_group, vrouter_name):
    '''
    Create a virtual router peering.

    Required Parameters:
    - name -- The name of the Virtual Router Peering
    - peer_asn -- Peer ASN. Its range is from 1 to 4294967295.
    - peer_ip -- Peer IP address.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vrouter_name -- The name of the Virtual Router.
    '''
    return _call_az("az network vrouter peering create", locals())


def update(name, resource_group, vrouter_name, add=None, force_string=None, peer_asn=None, peer_ip=None, remove=None, set=None):
    '''
    Update a virtual router peering.

    Required Parameters:
    - name -- The name of the Virtual Router Peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vrouter_name -- The name of the Virtual Router.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - peer_asn -- Peer ASN. Its range is from 1 to 4294967295.
    - peer_ip -- Peer IP address.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network vrouter peering update", locals())


def delete(name, resource_group, vrouter_name):
    '''
    Delete a virtual router peering.

    Required Parameters:
    - name -- The name of the Virtual Router Peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vrouter_name -- The name of the Virtual Router.
    '''
    return _call_az("az network vrouter peering delete", locals())


def show(name, resource_group, vrouter_name):
    '''
    Show a virtual router peering

    Required Parameters:
    - name -- The name of the Virtual Router Peering
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vrouter_name -- The name of the Virtual Router.
    '''
    return _call_az("az network vrouter peering show", locals())


def list(resource_group, vrouter_name):
    '''
    List all virtual router peerings under a resource group.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vrouter_name -- The name of the Virtual Router.
    '''
    return _call_az("az network vrouter peering list", locals())




from ... pyaz_utils import _call_az
from . import managed, self_hosted


def list(resource_group, workspace_name):
    '''
    List integration runtimes.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime list", locals())


def show(name, resource_group, workspace_name, if_none_match=None):
    '''
    Get an integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - if_none_match -- ETag of the integration runtime entity. Should only be specified for get. If the ETag matches the existing entity tag, or if * was provided, then no content will be returned.
    '''
    return _call_az("az synapse integration-runtime show", locals())


def create(name, resource_group, type, workspace_name, compute_type=None, core_count=None, description=None, if_match=None, location=None, no_wait=None, time_to_live=None):
    '''
    Create an integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- The integration runtime type.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - compute_type -- Compute type of the data flow cluster which will execute data flow job.
    - core_count -- Core count of the data flow cluster which will execute data flow job.
    - description -- The integration runtime description.
    - if_match -- ETag of the integration runtime entity. Should only be specified for update, for which it should match existing entity or can be * for unconditional update.
    - location -- The integration runtime location.
    - no_wait -- Do not wait for the long-running operation to finish.
    - time_to_live -- Time to live (in minutes) setting of the data flow cluster which will execute data flow job.
    '''
    return _call_az("az synapse integration-runtime create", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete an integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse integration-runtime delete", locals())


def update(auto_update, name, resource_group, update_delay_offset, workspace_name):
    '''
    Update an integration runtime.

    Required Parameters:
    - auto_update -- Enable or disable the self-hosted integration runtime auto-update.
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - update_delay_offset -- The time of the day for the self-hosted integration runtime auto-update.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime update", locals())


def start(name, resource_group, workspace_name, no_wait=None):
    '''
    start an SSIS integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse integration-runtime start", locals())


def stop(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    stop an SSIS integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse integration-runtime stop", locals())


def upgrade(name, resource_group, workspace_name):
    '''
    Upgrade self-hosted integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime upgrade", locals())


def list_auth_key(name, resource_group, workspace_name):
    '''
    Get keys for a self-hosted integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime list-auth-key", locals())


def regenerate_auth_key(name, resource_group, workspace_name, key_name=None):
    '''
    Regenerate self-hosted integration runtime key.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - key_name -- The name of the authentication key to regenerate.
    '''
    return _call_az("az synapse integration-runtime regenerate-auth-key", locals())


def get_monitoring_data(name, resource_group, workspace_name):
    '''
    Get metric data for a self-hosted integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime get-monitoring-data", locals())


def sync_credentials(name, resource_group, workspace_name):
    '''
    Synchronize credentials among integration runtime nodes.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime sync-credentials", locals())


def get_connection_info(name, resource_group, workspace_name):
    '''
    Get the integration runtime connection infomation.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime get-connection-info", locals())


def get_status(name, resource_group, workspace_name):
    '''
    Gets detailed status information for an integration runtime.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse integration-runtime get-status", locals())


def wait(name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, if_none_match=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a integration runtime is met.

    Required Parameters:
    - name -- The integration runtime name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - if_none_match -- ETag of the integration runtime entity. Should only be specified for get. If the ETag matches the existing entity tag, or if * was provided, then no content will be returned.
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse integration-runtime wait", locals())




from ..... pyaz_utils import _call_az

def show(name, partner_namespace_name, resource_group):
    '''
    Get the details of an event channel under a partner namespace.

    Required Parameters:
    - name -- Name of the event channel.
    - partner_namespace_name -- Name of the partner namespace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid partner namespace event-channel show", locals())


def delete(name, partner_namespace_name, resource_group, yes=None):
    '''
    Delete a partner namespace.

    Required Parameters:
    - name -- Name of the event channel.
    - partner_namespace_name -- Name of the partner namespace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az eventgrid partner namespace event-channel delete", locals())


def list(partner_namespace_name, resource_group, odata_query=None):
    '''
    List available partner event-channels.

    Required Parameters:
    - partner_namespace_name -- Name of the partner namespace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - odata_query -- The OData query used for filtering the list results. Filtering is currently allowed on the Name property only. The supported operations include: CONTAINS, eq (for equal), ne (for not equal), AND, OR and NOT.
    '''
    return _call_az("az eventgrid partner namespace event-channel list", locals())


def create(destination_resource_group_name, destination_subscription_id, destination_topic_name, name, partner_namespace_name, resource_group, source, activation_expiration_date=None, partner_topic_description=None, publisher_filter=None):
    '''
    Create an event channel under a partner namespace.

    Required Parameters:
    - destination_resource_group_name -- Azure Resource Group of the customer creating the event channel. The partner topic associated with the event channel will be created under this resource group.
    - destination_subscription_id -- Azure subscription Id of the customer creating the event channel. The partner topic associated with the event channel will be created under this Azure subscription.
    - destination_topic_name -- Name of the partner topic associated with the event channel.
    - name -- Name of the event channel.
    - partner_namespace_name -- Name of the partner namespace.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source -- The identifier of the resource that forms the partner source of the events. This represents a unique resource in the partner's resource model.

    Optional Parameters:
    - activation_expiration_date -- Date or datetime in UTC ISO 8601 format (e.g., '2022-02-17T01:59:59+00:00' or '2022-02-17') after which the event channel and corresponding partner topic would expire and get auto deleted. If this time is not specified, the expiration date is set to seven days by default.
    - partner_topic_description -- Friendly description of the corresponding partner topic. This will be helpful to remove any ambiguity of the origin of creation of the partner topic for the customer.
    - publisher_filter -- None
    '''
    return _call_az("az eventgrid partner namespace event-channel create", locals())




'''
Manage Azure Cosmos DB database accounts.
'''
from .. pyaz_utils import _call_az
from . import collection, database, identity, keys, locations, network_rule, private_endpoint_connection, private_link_resource, restorable_database_account, table


def show(name, resource_group):
    '''
    Get the details of an Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb show", locals())


def list_keys(name, resource_group):
    '''
    List the access keys for a Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb list-keys", locals())


def list_read_only_keys(name, resource_group):
    '''
    List the read-only access keys for a Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb list-read-only-keys", locals())


def list_connection_strings(name, resource_group):
    '''
    List the connection strings for a Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb list-connection-strings", locals())


def regenerate_key(key_kind, name, resource_group):
    '''
    Regenerate an access key for a Azure Cosmos DB database account.

    Required Parameters:
    - key_kind -- The access key to regenerate.
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb regenerate-key", locals())


def check_name_exists(name):
    '''
    Checks if an Azure Cosmos DB account name exists.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    '''
    return _call_az("az cosmosdb check-name-exists", locals())


def delete(name, resource_group, yes=None):
    '''
    Deletes an Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb delete", locals())


def failover_priority_change(failover_policies, name, resource_group):
    '''
    Changes the failover priority for the Azure Cosmos DB database account.

    Required Parameters:
    - failover_policies -- space-separated failover policies in 'regionName=failoverPriority' format. E.g eastus=0 westus=1
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb failover-priority-change", locals())


def create(name, resource_group, analytical_storage_schema_type=None, assign_identity=None, backup_interval=None, backup_policy_type=None, backup_redundancy=None, backup_retention=None, capabilities=None, databases_to_restore=None, default_consistency_level=None, default_identity=None, disable_key_based_metadata_write_access=None, enable_analytical_storage=None, enable_automatic_failover=None, enable_free_tier=None, enable_multiple_write_locations=None, enable_public_network=None, enable_virtual_network=None, ip_range_filter=None, is_restore_request=None, key_uri=None, kind=None, locations=None, max_interval=None, max_staleness_prefix=None, network_acl_bypass=None, network_acl_bypass_resource_ids=None, restore_source=None, restore_timestamp=None, server_version=None, tags=None, virtual_network_rules=None):
    '''
    Creates a new Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - analytical_storage_schema_type -- Schema type for analytical storage.
    - assign_identity -- Assign system or user assigned identities separated by spaces. Use '[system]' to refer system assigned identity.
    - backup_interval -- the frequency(in minutes) with which backups are taken (only for accounts with periodic mode backups)
    - backup_policy_type -- The type of backup policy of the account to create
    - backup_redundancy -- The redundancy type of the backup Storage account
    - backup_retention -- the time(in hours) for which each backup is retained (only for accounts with periodic mode backups)
    - capabilities -- set custom capabilities on the Cosmos DB database account.
    - databases_to_restore -- None
    - default_consistency_level -- default consistency level of the Cosmos DB database account
    - default_identity -- The primary identity to access key vault in CMK related features. e.g. 'FirstPartyIdentity', 'SystemAssignedIdentity' and more.
    - disable_key_based_metadata_write_access -- Disable write operations on metadata resources (databases, containers, throughput) via account keys
    - enable_analytical_storage -- Flag to enable log storage on the account.
    - enable_automatic_failover -- Enables automatic failover of the write region in the rare event that the region is unavailable due to an outage. Automatic failover will result in a new write region for the account and is chosen based on the failover priorities configured for the account.
    - enable_free_tier -- If enabled the account is free-tier.
    - enable_multiple_write_locations -- Enable Multiple Write Locations
    - enable_public_network -- Enable or disable public network access to server.
    - enable_virtual_network -- Enables virtual network on the Cosmos DB database account
    - ip_range_filter -- firewall support. Specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account. IP addresses/ranges must be comma-separated and must not contain any spaces
    - is_restore_request -- Restore from an existing/deleted account.
    - key_uri -- The URI of the key vault
    - kind -- The type of Cosmos DB database account to create
    - locations -- None
    - max_interval -- when used with Bounded Staleness consistency, this value represents the time amount of staleness (in seconds) tolerated. Accepted range for this value is 1 - 100
    - max_staleness_prefix -- when used with Bounded Staleness consistency, this value represents the number of stale requests tolerated. Accepted range for this value is 1 - 2,147,483,647
    - network_acl_bypass -- Flag to enable or disable Network Acl Bypass.
    - network_acl_bypass_resource_ids -- List of Resource Ids to allow Network Acl Bypass.
    - restore_source -- The restorable-database-account Id of the source account from which the account has to be restored. Required if --is-restore-request is set to true.
    - restore_timestamp -- The timestamp to which the account has to be restored to. Required if --is-restore-request is set to true.
    - server_version -- Valid only for MongoDB accounts.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - virtual_network_rules -- ACL's for virtual network
    '''
    return _call_az("az cosmosdb create", locals())


def update(name, resource_group, analytical_storage_schema_type=None, backup_interval=None, backup_policy_type=None, backup_redundancy=None, backup_retention=None, capabilities=None, default_consistency_level=None, default_identity=None, disable_key_based_metadata_write_access=None, enable_analytical_storage=None, enable_automatic_failover=None, enable_multiple_write_locations=None, enable_public_network=None, enable_virtual_network=None, ip_range_filter=None, locations=None, max_interval=None, max_staleness_prefix=None, network_acl_bypass=None, network_acl_bypass_resource_ids=None, server_version=None, tags=None, virtual_network_rules=None):
    '''
    Update an Azure Cosmos DB database account.

    Required Parameters:
    - name -- Name of the Cosmos DB database account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - analytical_storage_schema_type -- Schema type for analytical storage.
    - backup_interval -- the frequency(in minutes) with which backups are taken (only for accounts with periodic mode backups)
    - backup_policy_type -- The type of backup policy of the account to create
    - backup_redundancy -- The redundancy type of the backup Storage account
    - backup_retention -- the time(in hours) for which each backup is retained (only for accounts with periodic mode backups)
    - capabilities -- set custom capabilities on the Cosmos DB database account.
    - default_consistency_level -- default consistency level of the Cosmos DB database account
    - default_identity -- The primary identity to access key vault in CMK related features. e.g. 'FirstPartyIdentity', 'SystemAssignedIdentity' and more.
    - disable_key_based_metadata_write_access -- Disable write operations on metadata resources (databases, containers, throughput) via account keys
    - enable_analytical_storage -- Flag to enable log storage on the account.
    - enable_automatic_failover -- Enables automatic failover of the write region in the rare event that the region is unavailable due to an outage. Automatic failover will result in a new write region for the account and is chosen based on the failover priorities configured for the account.
    - enable_multiple_write_locations -- Enable Multiple Write Locations
    - enable_public_network -- Enable or disable public network access to server.
    - enable_virtual_network -- Enables virtual network on the Cosmos DB database account
    - ip_range_filter -- firewall support. Specifies the set of IP addresses or IP address ranges in CIDR form to be included as the allowed list of client IPs for a given database account. IP addresses/ranges must be comma-separated and must not contain any spaces
    - locations -- None
    - max_interval -- when used with Bounded Staleness consistency, this value represents the time amount of staleness (in seconds) tolerated. Accepted range for this value is 1 - 100
    - max_staleness_prefix -- when used with Bounded Staleness consistency, this value represents the number of stale requests tolerated. Accepted range for this value is 1 - 2,147,483,647
    - network_acl_bypass -- Flag to enable or disable Network Acl Bypass.
    - network_acl_bypass_resource_ids -- List of Resource Ids to allow Network Acl Bypass.
    - server_version -- Valid only for MongoDB accounts.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - virtual_network_rules -- ACL's for virtual network
    '''
    return _call_az("az cosmosdb update", locals())


def list(resource_group=None):
    '''
    List Azure Cosmos DB database accounts.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb list", locals())


def restore(account_name, location, resource_group, restore_timestamp, target_database_account_name, databases_to_restore=None):
    '''
    Create a new Azure Cosmos DB database account by restoring from an existing database account.

    Required Parameters:
    - account_name -- Name of the source Cosmos DB database account for the restore
    - location -- The location of the source account from which restore is triggered. This will also be the write region of the restored account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - restore_timestamp -- The timestamp to which the account has to be restored to.
    - target_database_account_name -- Name of the new target Cosmos DB database account after the restore

    Optional Parameters:
    - databases_to_restore -- None
    '''
    return _call_az("az cosmosdb restore", locals())




'''
Manage Synapse's triggers.
'''
from ... pyaz_utils import _call_az

def create(file, name, workspace_name, no_wait=None):
    '''
    Create a trigger.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The trigger name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse trigger create", locals())


def set(file, name, workspace_name, no_wait=None):
    '''
    Update an exist trigger.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The trigger name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse trigger set", locals())


def update(file, name, workspace_name, no_wait=None):
    '''
    Update an exist trigger.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The trigger name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse trigger update", locals())


def list(workspace_name):
    '''
    List triggers.

    Required Parameters:
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse trigger list", locals())


def show(name, workspace_name):
    '''
    Get a trigger.

    Required Parameters:
    - name -- The trigger name.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse trigger show", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a trigger.

    Required Parameters:
    - name -- The trigger name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse trigger delete", locals())


def subscribe_to_event(name, workspace_name, no_wait=None):
    '''
    Subscribe event trigger to events.

    Required Parameters:
    - name -- The trigger name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse trigger subscribe-to-event", locals())


def get_event_subscription_status(name, workspace_name):
    '''
    Get a trigger's event subscription status.

    Required Parameters:
    - name -- The trigger name.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse trigger get-event-subscription-status", locals())


def unsubscribe_from_event(name, workspace_name, no_wait=None):
    '''
    Unsubscribe event trigger from events.

    Required Parameters:
    - name -- The trigger name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse trigger unsubscribe-from-event", locals())


def start(name, workspace_name, no_wait=None):
    '''
    Starts a trigger.

    Required Parameters:
    - name -- The trigger name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse trigger start", locals())


def stop(name, workspace_name, no_wait=None):
    '''
    Stops a trigger.

    Required Parameters:
    - name -- The trigger name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse trigger stop", locals())


def wait(name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a trigger is met.

    Required Parameters:
    - name -- The trigger name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse trigger wait", locals())




from .... pyaz_utils import _call_az

def create(outbound_rule_fqdn, resource_group, server):
    '''
    Create a new outbound firewall rule.

    Required Parameters:
    - outbound_rule_fqdn -- The allowed FQDN for the outbound firewall rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server outbound-firewall-rule create", locals())


def delete(outbound_rule_fqdn, resource_group, server):
    '''
    Delete the outbound firewall rule.

    Required Parameters:
    - outbound_rule_fqdn -- The allowed FQDN for the outbound firewall rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server outbound-firewall-rule delete", locals())


def show(outbound_rule_fqdn, resource_group, server):
    '''
    Show the details for an outbound firewall rule.

    Required Parameters:
    - outbound_rule_fqdn -- The allowed FQDN for the outbound firewall rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server outbound-firewall-rule show", locals())


def list(resource_group, server):
    '''
    List a server's outbound firewall rules.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql server outbound-firewall-rule list", locals())




'''
Manage Azure Batch accounts.
'''
from ... pyaz_utils import _call_az
from . import autostorage_keys, keys


def list(resource_group=None):
    '''
    List the Batch accounts associated with a subscription or resource group.

    Optional Parameters:
    - resource_group -- Name of the resource group
    '''
    return _call_az("az batch account list", locals())


def show(name=None, resource_group=None):
    '''
    Get a specified Batch account or the currently set account.

    Optional Parameters:
    - name -- Name of the batch account to show. If not specified will display currently set account.
    - resource_group -- Name of the resource group. If not specified will display currently set account.
    '''
    return _call_az("az batch account show", locals())


def create(location, name, resource_group, encryption_key_identifier=None, encryption_key_source=None, identity_type=None, keyvault=None, no_wait=None, public_network_access=None, storage_account=None, tags=None):
    '''
    Create a Batch account with the specified parameters.

    Required Parameters:
    - location -- The region in which to create the account.
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group

    Optional Parameters:
    - encryption_key_identifier -- Part of the encryption configuration for the Batch account. Full path to the versioned secret. Example https://mykeyvault.vault.azure.net/keys/testkey/6e34a81fef704045975661e297a4c053.
    - encryption_key_source -- Part of the encryption configuration for the Batch account. Type of the key source. Can be either Microsoft.Batch or Microsoft.KeyVault
    - identity_type -- The type of identity used for the Batch account. Possible values include: 'SystemAssigned', 'None'.
    - keyvault -- The KeyVault name or resource ID to be used for an account with a pool allocation mode of 'User Subscription'.
    - no_wait -- Do not wait for the long-running operation to finish.
    - public_network_access -- The network access type for accessing Azure Batch account. Values can either be enabled or disabled.
    - storage_account -- The storage account name or resource ID to be used for auto storage.
    - tags -- Space-separated tags in 'key[=value]' format.
    '''
    return _call_az("az batch account create", locals())


def set(name, resource_group, encryption_key_identifier=None, encryption_key_source=None, identity_type=None, storage_account=None, tags=None):
    '''
    Update properties for a Batch account.

    Required Parameters:
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group

    Optional Parameters:
    - encryption_key_identifier -- Part of the encryption configuration for the Batch account. Full path to the versioned secret. Example https://mykeyvault.vault.azure.net/keys/testkey/6e34a81fef704045975661e297a4c053.
    - encryption_key_source -- Part of the encryption configuration for the Batch account. Type of the key source. Can be either Microsoft.Batch or Microsoft.KeyVault
    - identity_type -- The type of identity used for the Batch account. Possible values include: 'SystemAssigned', 'None'.
    - storage_account -- The storage account name or resource ID to be used for auto storage.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az batch account set", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    

    Required Parameters:
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch account delete", locals())


def login(name, resource_group, shared_key_auth=None, show=None):
    '''
    Log in to a Batch account through Azure Active Directory or Shared Key authentication.

    Required Parameters:
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group

    Optional Parameters:
    - shared_key_auth -- Using Shared Key authentication, if not specified, it will use Azure Active Directory authentication.
    - show -- Display the credential information for the Batch account.
    '''
    return _call_az("az batch account login", locals())


def outbound_endpoints(name, resource_group):
    '''
    List an account's outbound network dependencies.

    Required Parameters:
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group
    '''
    return _call_az("az batch account outbound-endpoints", locals())




from .... pyaz_utils import _call_az

def add(account_name, name, resource_group, base64_key=None, expiration=None, identifier=None):
    '''
    Add an AkamaiAccessControl to an existing streaming endpoint.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - base64_key -- Base64-encoded authentication key that will be used by the CDN. The authentication key provided by Akamai is an ASCII encoded string, and must be converted to bytes and then base64 encoded.
    - expiration -- The ISO 8601 DateTime value that specifies when the Akamai authentication expires.
    - identifier -- The identifier for the authentication key. This is the nonce provided by Akamai.
    '''
    return _call_az("az ams streaming-endpoint akamai add", locals())


def remove(account_name, identifier, name, resource_group):
    '''
    Remove an AkamaiAccessControl from an existing streaming endpoint.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - identifier -- The identifier for the authentication key. This is the nonce provided by Akamai.
    - name -- The name of the streaming endpoint.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-endpoint akamai remove", locals())




'''
Manage the metadata of a file share.
'''
from .... pyaz_utils import _call_az

def show(name, account_key=None, account_name=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  A string that represents the snapshot version, if applicable.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share metadata show", locals())


def update(name, account_key=None, account_name=None, connection_string=None, metadata=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The file share name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage share metadata update", locals())




from .... pyaz_utils import _call_az

def create(address_prefix, appliance_name, name, resource_group, allow=None, default=None, optimize=None):
    '''
    Create an Azure network virtual appliance site.

    Required Parameters:
    - address_prefix -- Address Prefix of Network Virtual Appliance Site
    - appliance_name -- The name of Network Virtual Appliance
    - name -- The name of Network Virtual Appliance Site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - allow -- Flag to control breakout of o365 allow category.
    - default -- Flag to control breakout of o365 default category.
    - optimize -- Flag to control breakout of o365 optimize category.
    '''
    return _call_az("az network virtual-appliance site create", locals())


def update(address_prefix, appliance_name, name, resource_group, add=None, allow=None, default=None, force_string=None, optimize=None, remove=None, set=None):
    '''
    Update an Azure network virtual appliance site.

    Required Parameters:
    - address_prefix -- Address Prefix of Network Virtual Appliance Site
    - appliance_name -- The name of Network Virtual Appliance
    - name -- The name of Network Virtual Appliance Site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - allow -- Flag to control breakout of o365 allow category.
    - default -- Flag to control breakout of o365 default category.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - optimize -- Flag to control breakout of o365 optimize category.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network virtual-appliance site update", locals())


def show(appliance_name, name, resource_group):
    '''
    Show the detail of an Azure network virtual appliance site.

    Required Parameters:
    - appliance_name -- The name of Network Virtual Appliance
    - name -- The name of Network Virtual Appliance Site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network virtual-appliance site show", locals())


def delete(appliance_name, name, resource_group, yes=None):
    '''
    Delete an Azure network virtual appliance site.

    Required Parameters:
    - appliance_name -- The name of Network Virtual Appliance
    - name -- The name of Network Virtual Appliance Site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network virtual-appliance site delete", locals())


def list(appliance_name, resource_group):
    '''
    List all Azure network virtual appliance site.

    Required Parameters:
    - appliance_name -- The name of Network Virtual Appliance
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network virtual-appliance site list", locals())




from ... pyaz_utils import _call_az

def create(account_name, archive_window_length, asset_name, live_event_name, name, resource_group, description=None, fragments_per_ts_segment=None, manifest_name=None, output_snap_time=None):
    '''
    Create a live output.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - archive_window_length -- ISO 8601 timespan duration of the archive window length. This is the duration that customer want to retain the recorded content. Minimum window is 5 minutes (PT5M or 00:05:00). Maximum window is 25 hours (PT25H or 25:00:00). For example, to retain the output for 10 minutes, use PT10M or 00:10:00
    - asset_name -- The name of the asset.
    - live_event_name -- The name of the live event.
    - name -- The name of the live output.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - description -- The live output description.
    - fragments_per_ts_segment -- The number of fragments per HLS segment.
    - manifest_name -- The manifest file name. If not provided, the service will generate one automatically.
    - output_snap_time -- The output snapshot time.
    '''
    return _call_az("az ams live-output create", locals())


def show(account_name, live_event_name, name, resource_group):
    '''
    Show the details of a live output.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - live_event_name -- The name of the live event.
    - name -- The name of the live output.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams live-output show", locals())


def list(account_name, live_event_name, resource_group):
    '''
    List all the live outputs in a live event.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - live_event_name -- The name of the live event.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams live-output list", locals())


def delete(account_name, live_event_name, name, resource_group):
    '''
    Delete a live output.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - live_event_name -- The name of the live event.
    - name -- The name of the live output.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams live-output delete", locals())




'''
Manage read replicas.
'''
from .... pyaz_utils import _call_az

def list(resource_group, server_name):
    '''
    List all read replicas for a given server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the master server.
    '''
    return _call_az("az mysql server replica list", locals())


def create(name, resource_group, source_server, location=None, no_wait=None, sku_name=None):
    '''
    Create a read replica for a server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_server -- The name or resource ID of the master server to the create replica for.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. If not provided, the create replica will be in the same location as the master server
    - no_wait -- Do not wait for the long-running operation to finish.
    - sku_name -- The name of the sku. Follows the convention {pricing tier}_{compute generation}_{vCores} in shorthand. Examples: B_Gen5_1, GP_Gen5_4, MO_Gen5_16.
    '''
    return _call_az("az mysql server replica create", locals())


def stop(name, resource_group, yes=None):
    '''
    Stop replication to a read replica and make it a read/write server.

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az mysql server replica stop", locals())




from ... pyaz_utils import _call_az

def list(account_name, invoice_section_name=None, profile_name=None):
    '''
    List the role definitions for a billing account. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - invoice_section_name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing role-definition list", locals())


def show(account_name, name, invoice_section_name=None, profile_name=None):
    '''
    Show the role definition details

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The name that uniquely identifies a role definition.

    Optional Parameters:
    - invoice_section_name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing role-definition show", locals())




'''
Manage Azure IoT Hub Device Provisioning Service.
'''
from ... pyaz_utils import _call_az
from . import access_policy, certificate, linked_hub


def list(resource_group=None):
    '''
    List Azure IoT Hub device provisioning services.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps list", locals())


def show(name, resource_group=None):
    '''
    Get the details of an Azure IoT Hub device provisioning service.

    Required Parameters:
    - name -- IoT Provisioning Service name

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps show", locals())


def create(name, resource_group, location=None, sku=None, tags=None, unit=None):
    '''
    Create an Azure IoT Hub device provisioning service.

    Required Parameters:
    - name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location of your IoT Provisioning Service. Default is the location of target resource group.
    - sku -- Pricing tier for the IoT provisioning service.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - unit -- Units in your IoT Provisioning Service.
    '''
    return _call_az("az iot dps create", locals())


def delete(name, resource_group):
    '''
    Delete an Azure IoT Hub device provisioning service.

    Required Parameters:
    - name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update an Azure IoT Hub device provisioning service.

    Required Parameters:
    - name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az iot dps update", locals())




'''
Manage Azure DevTest Labs.
'''
from .. pyaz_utils import _call_az
from . import arm_template, artifact, artifact_source, custom_image, environment, formula, gallery_image, secret, vm, vnet


def get(name, resource_group, expand=None):
    '''
    

    Required Parameters:
    - name -- The name of the lab.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Specify the $expand query. Example: 'properties($select=defaultStorageAccount)'
    '''
    return _call_az("az lab get", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the lab.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az lab delete", locals())




'''
Manage directories in Azure Data Lake Storage Gen2 account.
'''
from .... pyaz_utils import _call_az
from . import metadata


def create(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, metadata=None, permissions=None, sas_token=None, timeout=None, umask=None):
    '''
    Create a directory in ADLS Gen2 file system.

    Required Parameters:
    - name -- The name of directory.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - permissions -- POSIX access permissions for the file owner, the file owning group, and others. Each class may be granted read, write, or execute permission. The sticky bit is also supported. Both symbolic (rwxrw-rw-) and 4-digit octal notation (e.g. 0766) are supported. For more information, please refer to https://docs.microsoft.com/azure/storage/blobs/data-lake-storage-access-control#levels-of-permission.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - umask -- When creating a file or directory and the parent folder does not have a default ACL, the umask restricts the permissions of the file or directory to be created. The resulting permission is given by p & ^u, where p is the permission and u is the umask. For more information, please refer to https://docs.microsoft.com/azure/storage/blobs/data-lake-storage-access-control#umask.
    '''
    return _call_az("az storage fs directory create", locals())


def exists(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Check for the existence of a directory in ADLS Gen2 file system.

    Required Parameters:
    - name -- The name of directory.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs directory exists", locals())


def show(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Show properties of a directory in ADLS Gen2 file system.

    Required Parameters:
    - name -- The name of directory.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs directory show", locals())


def delete(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None, yes=None):
    '''
    Delete a directory in ADLS Gen2 file system.

    Required Parameters:
    - name -- The name of directory.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az storage fs directory delete", locals())


def move(name, new_directory, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Move a directory in ADLS Gen2 file system.

    Required Parameters:
    - name -- The name of directory.
    - new_directory -- The new directory name the users want to move to. The value must have the following format: "{filesystem}/{directory}/{subdirectory}".

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs directory move", locals())


def list(account_key=None, account_name=None, auth_mode=None, connection_string=None, num_results=None, path=None, recursive=None, sas_token=None, timeout=None):
    '''
    List directories in ADLS Gen2 file system.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - num_results -- Specify the maximum number of results to return.
    - path -- Filter the results to return only paths under the specified path.
    - recursive -- Look into sub-directories recursively when set to true.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs directory list", locals())


def upload(file_system, source, account_key=None, account_name=None, auth_mode=None, connection_string=None, destination_path=None, recursive=None, sas_token=None):
    '''
    Upload files or subdirectories to a directory in ADLS Gen2 file system.

    Required Parameters:
    - file_system -- The upload destination file system.
    - source -- The source file path to upload from.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - destination_path -- The upload destination directory path. It should be an absolute path to file system. If the specified destination path does not exist, a new directory path will be created.
    - recursive -- Recursively upload files. If enabled, all the files including the files in subdirectories will be uploaded.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage fs directory upload", locals())


def download(destination_path, file_system, account_key=None, account_name=None, auth_mode=None, connection_string=None, recursive=None, sas_token=None, source_path=None):
    '''
    Download files from the directory in ADLS Gen2 file system to a local file path.

    Required Parameters:
    - destination_path -- The destination local directory path to download.
    - file_system -- The download source file system.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - recursive -- Recursively download files. If enabled, all the files including the files in subdirectories will be downloaded.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - source_path -- The download source directory path. It should be an absolute path to file system.
    '''
    return _call_az("az storage fs directory download", locals())




from ..... pyaz_utils import _call_az

def list(name, namespace_name, resource_group, topic_name):
    '''
    List the keys and connection strings of Authorization Rule for Service Bus Topic.

    Required Parameters:
    - name -- name of Topic Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - topic_name -- Name of Topic
    '''
    return _call_az("az servicebus topic authorization-rule keys list", locals())


def renew(name, namespace_name, resource_group, topic_name, key=None, key_value=None):
    '''
    Regenerate keys of Authorization Rule for Service Bus Topic.

    Required Parameters:
    - name -- Name of Topic Authorization Rule
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - topic_name -- name of Topic

    Optional Parameters:
    - key -- specifies Primary or Secondary key needs to be reset
    - key_value -- Optional, if the key value provided, is set for KeyType or autogenerated Key value set for keyType.
    '''
    return _call_az("az servicebus topic authorization-rule keys renew", locals())




'''
Manage shared access keys of a topic.
'''
from .... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    List shared access keys of a topic.

    Required Parameters:
    - name -- Name of the topic
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid topic key list", locals())


def regenerate(key_name, name, resource_group):
    '''
    Regenerate a shared access key of a topic.

    Required Parameters:
    - key_name -- Key name to regenerate key1 or key2
    - name -- Name of the topic
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid topic key regenerate", locals())




'''
Manage storage service logging information.
'''
from ... pyaz_utils import _call_az

def update(log, retention, services, account_key=None, account_name=None, connection_string=None, sas_token=None, timeout=None, version=None):
    '''
    Update logging settings for a storage account.

    Required Parameters:
    - log -- None
    - retention -- None
    - services -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - version -- None
    '''
    return _call_az("az storage logging update", locals())


def show(account_key=None, account_name=None, connection_string=None, sas_token=None, services=None, timeout=None):
    '''
    Show logging settings for a storage account.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - services -- None
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage logging show", locals())


def off(account_key=None, account_name=None, connection_string=None, sas_token=None, services=None, timeout=None):
    '''
    Turn off logging for a storage account.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - services -- None
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage logging off", locals())




from .... pyaz_utils import _call_az

def list(lb_name, resource_group):
    '''
    List inbound NAT rules.

    Required Parameters:
    - lb_name -- The name of the load balancer.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb inbound-nat-rule list", locals())


def show(lb_name, name, resource_group):
    '''
    Get the details of an inbound NAT rule.

    Required Parameters:
    - lb_name -- The name of the load balancer.
    - name -- The name of the inbound NAT rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb inbound-nat-rule show", locals())


def delete(lb_name, name, resource_group):
    '''
    Delete an inbound NAT rule.

    Required Parameters:
    - lb_name -- The name of the load balancer.
    - name -- The name of the inbound NAT rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb inbound-nat-rule delete", locals())


def create(backend_port, lb_name, name, protocol, resource_group, enable_tcp_reset=None, floating_ip=None, frontend_ip_name=None, frontend_port=None, frontend_port_range_end=None, frontend_port_range_start=None, idle_timeout=None):
    '''
    Create an inbound NAT rule.

    Required Parameters:
    - backend_port -- Port number
    - lb_name -- The load balancer name.
    - name -- The name of the inbound NAT rule
    - protocol -- Network transport protocol.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - enable_tcp_reset -- Receive bidirectional TCP reset on TCP flow idle timeout or unexpected connection termination. Only used when protocol is set to TCP.
    - floating_ip -- Enable floating IP.
    - frontend_ip_name -- The name of the frontend IP configuration. If only one exists, omit to use as default.
    - frontend_port -- Port number
    - frontend_port_range_end -- Port number
    - frontend_port_range_start -- Port number
    - idle_timeout -- Idle timeout in minutes.
    '''
    return _call_az("az network lb inbound-nat-rule create", locals())


def update(lb_name, name, resource_group, add=None, backend_port=None, enable_tcp_reset=None, floating_ip=None, force_string=None, frontend_ip_name=None, frontend_port=None, frontend_port_range_end=None, frontend_port_range_start=None, idle_timeout=None, protocol=None, remove=None, set=None):
    '''
    Update an inbound NAT rule.

    Required Parameters:
    - lb_name -- The load balancer name.
    - name -- The name of the inbound NAT rule
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - backend_port -- Port number
    - enable_tcp_reset -- Receive bidirectional TCP reset on TCP flow idle timeout or unexpected connection termination. Only used when protocol is set to TCP.
    - floating_ip -- Enable floating IP.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - frontend_ip_name -- The name of the frontend IP configuration.
    - frontend_port -- Port number
    - frontend_port_range_end -- Port number
    - frontend_port_range_start -- Port number
    - idle_timeout -- Idle timeout in minutes.
    - protocol -- Network transport protocol.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network lb inbound-nat-rule update", locals())




'''
Manage AFD profiles.
'''
from ... pyaz_utils import _call_az

def show(profile_name, resource_group):
    '''
    Show details of an AFD profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd profile show", locals())


def delete(profile_name, resource_group):
    '''
    Delete an AFD profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd profile delete", locals())


def update(profile_name, resource_group, tags):
    '''
    Update an AFD profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az afd profile update", locals())


def list(resource_group=None):
    '''
    List AFD profiles.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd profile list", locals())


def create(profile_name, resource_group, sku, tags=None):
    '''
    Create a new AFD profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- The pricing tier of the AFD profile.

    Optional Parameters:
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az afd profile create", locals())


def usage(profile_name, resource_group):
    '''
    List resource usage within the specific AFD profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd profile usage", locals())




'''
billing account
'''
from ... pyaz_utils import _call_az

def list(expand=None):
    '''
    List the billing accounts that a user has access to.

    Optional Parameters:
    - expand -- May be used to expand the soldTo, invoice sections and billing profiles.
    '''
    return _call_az("az billing account list", locals())


def show(name, expand=None):
    '''
    Get a billing account by its ID.

    Required Parameters:
    - name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - expand -- May be used to expand the soldTo, invoice sections and billing profiles.
    '''
    return _call_az("az billing account show", locals())


def update(name, billing_profiles_value=None, departments=None, display_name=None, enrollment_accounts=None, no_wait=None, sold_to=None):
    '''
    Update the properties of a billing account. Currently, displayName and address can be updated. The operation is supported only for billing accounts with agreement type Microsoft Customer Agreement.

    Required Parameters:
    - name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - billing_profiles_value -- The billing profiles associated with the billing account. Expected value: json-string/@json-file.
    - departments -- The departments associated to the enrollment. Expected value: json-string/@json-file.
    - display_name -- The billing account name.
    - enrollment_accounts -- The accounts associated to the enrollment. Expected value: json-string/@json-file.
    - no_wait -- Do not wait for the long-running operation to finish.
    - sold_to -- The address of the individual or organization that is responsible for the billing account.
    '''
    return _call_az("az billing account update", locals())


def wait(name, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the billing account is met.

    Required Parameters:
    - name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - expand -- May be used to expand the soldTo, invoice sections and billing profiles.
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az billing account wait", locals())




'''
Manage Azure Kusto databases.
'''
from ... pyaz_utils import _call_az

def create(cluster_name, name, resource_group, hot_cache_period=None, no_wait=None, soft_delete_period=None):
    '''
    Create a Kusto database.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The name of the database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - hot_cache_period -- Amount of time that data should be kept in cache.Duration in ISO8601 format (for example, 100 days would be P100D).
    - no_wait -- Do not wait for the long-running operation to finish.
    - soft_delete_period -- Amount of time that data should be kept so it is available to query. Duration in ISO8601 format (for example, 100 days would be P100D).
    '''
    return _call_az("az kusto database create", locals())


def delete(cluster_name, name, resource_group, yes=None):
    '''
    Delete a Kusto database.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The name of the database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az kusto database delete", locals())


def update(cluster_name, name, resource_group, soft_delete_period, add=None, force_string=None, hot_cache_period=None, no_wait=None, remove=None, set=None):
    '''
    Update a Kusto database.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The name of the database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - soft_delete_period -- Amount of time that data should be kept so it is available to query. Duration in ISO8601 format (for example, 100 days would be P100D).

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - hot_cache_period -- Amount of time that data should be kept in cache.Duration in ISO8601 format (for example, 100 days would be P100D).
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az kusto database update", locals())


def list(cluster_name, resource_group):
    '''
    List a Kusto database.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az kusto database list", locals())


def show(cluster_name, name, resource_group):
    '''
    Get a Kusto database.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The name of the database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az kusto database show", locals())


def wait(cluster_name, name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for a managed Kusto database to reach a desired state.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - name -- The name of the database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az kusto database wait", locals())




'''
Manage subnets in an Azure Virtual Network.
'''
from .... pyaz_utils import _call_az

def create(address_prefixes, name, resource_group, vnet_name, delegations=None, disable_private_endpoint_network_policies=None, disable_private_link_service_network_policies=None, nat_gateway=None, network_security_group=None, route_table=None, service_endpoint_policy=None, service_endpoints=None):
    '''
    Create a subnet and associate an existing NSG and route table.

    Required Parameters:
    - address_prefixes -- Space-separated list of address prefixes in CIDR format.
    - name -- The subnet name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.

    Optional Parameters:
    - delegations -- Space-separated list of services to whom the subnet should be delegated. (e.g. Microsoft.Sql/servers)
    - disable_private_endpoint_network_policies -- Disable private endpoint network policies on the subnet.
    - disable_private_link_service_network_policies -- Disable private link service network policies on the subnet.
    - nat_gateway -- Name or ID of a NAT gateway to attach.
    - network_security_group -- Name or ID of a network security group (NSG).
    - route_table -- Name or ID of a route table to associate with the subnet.
    - service_endpoint_policy -- Space-separated list of names or IDs of service endpoint policies to apply.
    - service_endpoints -- None
    '''
    return _call_az("az network vnet subnet create", locals())


def delete(name, resource_group, vnet_name):
    '''
    Delete a subnet.

    Required Parameters:
    - name -- The subnet name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.
    '''
    return _call_az("az network vnet subnet delete", locals())


def show(name, resource_group, vnet_name, expand=None):
    '''
    Show details of a subnet.

    Required Parameters:
    - name -- The subnet name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.

    Optional Parameters:
    - expand -- Expands referenced resources.
    '''
    return _call_az("az network vnet subnet show", locals())


def list(resource_group, vnet_name):
    '''
    List the subnets in a virtual network.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.
    '''
    return _call_az("az network vnet subnet list", locals())


def update(name, resource_group, vnet_name, add=None, address_prefixes=None, delegations=None, disable_private_endpoint_network_policies=None, disable_private_link_service_network_policies=None, force_string=None, nat_gateway=None, network_security_group=None, remove=None, route_table=None, service_endpoint_policy=None, service_endpoints=None, set=None):
    '''
    Update a subnet.

    Required Parameters:
    - name -- The subnet name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vnet_name -- The virtual network (VNet) name.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - address_prefixes -- Space-separated list of address prefixes in CIDR format.
    - delegations -- Space-separated list of services to whom the subnet should be delegated. (e.g. Microsoft.Sql/servers)
    - disable_private_endpoint_network_policies -- Disable private endpoint network policies on the subnet.
    - disable_private_link_service_network_policies -- Disable private link service network policies on the subnet.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - nat_gateway -- Name or ID of a NAT gateway to attach.
    - network_security_group -- Name or ID of a network security group (NSG). Use empty string ""('""' in PowerShell) to detach it.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - route_table -- Name or ID of a route table to associate with the subnet. Use empty string ""('""' in PowerShell) to detach it. You can also append "--remove routeTable" in "az network vnet subnet update" to detach it.
    - service_endpoint_policy -- Space-separated list of names or IDs of service endpoint policies to apply.
    - service_endpoints -- None
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network vnet subnet update", locals())


def list_available_delegations(location=None, resource_group=None):
    '''
    List the services available for subnet delegation.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet subnet list-available-delegations", locals())




'''
Manage the reliability of a cluster.
'''
from .... pyaz_utils import _call_az

def update(cluster_name, reliability_level, resource_group, auto_add_node=None):
    '''
    Update the reliability tier for the primary node in a cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - reliability_level -- durability level.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - auto_add_node -- Add node count automatically when changing reliability.
    '''
    return _call_az("az sf cluster reliability update", locals())




'''
Manage Data Lake Analytics catalog credentials.
'''
from .... pyaz_utils import _call_az

def create(account, credential_name, database_name, uri, user_name, password=None):
    '''
    Create a new catalog credential for use with an external data source.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - credential_name -- None
    - database_name -- None
    - uri -- URI of the external data source.
    - user_name -- None

    Optional Parameters:
    - password -- Password for the credential user. Will prompt if not given.
    '''
    return _call_az("az dla catalog credential create", locals())


def show(account, credential_name, database_name):
    '''
    Retrieve a catalog credential.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - credential_name -- The name of the credential.
    - database_name -- The name of the database containing the schema.
    '''
    return _call_az("az dla catalog credential show", locals())


def update(account, credential_name, database_name, uri, user_name, new_password=None, password=None):
    '''
    Update a catalog credential for use with an external data source.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - credential_name -- None
    - database_name -- None
    - uri -- URI of the external data source.
    - user_name -- None

    Optional Parameters:
    - new_password -- New password for the credential user. Will prompt if not given.
    - password -- Current password for the credential user. Will prompt if not given.
    '''
    return _call_az("az dla catalog credential update", locals())


def list(account, database_name, count=None, filter=None, orderby=None, select=None, skip=None, top=None):
    '''
    List catalog credentials.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - database_name -- The name of the database containing the schema.

    Optional Parameters:
    - count -- The Boolean value of true or false to request a count of the matching resources included with the resources in the response, e.g. Categories?$count=true.
    - filter -- OData filter. Optional.
    - orderby -- OrderBy clause. One or more comma-separated expressions with an optional "asc" (the default) or "desc" depending on the order you'd like the values sorted, e.g. Categories?$orderby=CategoryName desc. Optional.
    - select -- OData Select statement. Limits the properties on each entry to just those requested, e.g. Categories?$select=CategoryName,Description. Optional.
    - skip -- The number of items to skip over before returning elements.
    - top -- Maximum number of items to return.
    '''
    return _call_az("az dla catalog credential list", locals())


def delete(account, credential_name, database_name, cascade=None, password=None):
    '''
    Delete a catalog credential.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - credential_name -- The name of the credential to delete
    - database_name -- The name of the database containing the credential.

    Optional Parameters:
    - cascade -- Indicates if the delete should be a cascading delete (which deletes all resources dependent on the credential as well as the credential) or not. If false will fail if there are any resources relying on the credential.
    - password -- the current password for the credential and user with access to the data source. This is required if the requester is not the account owner.
    '''
    return _call_az("az dla catalog credential delete", locals())




'''
Manage partner topics.
'''
from .... pyaz_utils import _call_az
from . import event_subscription


def show(name, resource_group):
    '''
    Get the details of a partner topic.

    Required Parameters:
    - name -- Name of the partner topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid partner topic show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a partner topic.

    Required Parameters:
    - name -- Name of the partner topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az eventgrid partner topic delete", locals())


def activate(name, resource_group):
    '''
    Activate a partner topic.

    Required Parameters:
    - name -- Name of the partner topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid partner topic activate", locals())


def deactivate(name, resource_group):
    '''
    Deactivate a partner topic.

    Required Parameters:
    - name -- Name of the partner topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid partner topic deactivate", locals())


def list(odata_query=None, resource_group=None):
    '''
    List available partner topics.

    Optional Parameters:
    - odata_query -- The OData query used for filtering the list results. Filtering is currently allowed on the Name property only. The supported operations include: CONTAINS, eq (for equal), ne (for not equal), AND, OR and NOT.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid partner topic list", locals())

